/*
 * include/common/hash.h
 * Macros for different hashing function.
 *
 * Copyright (C) 2000-2011 Willy Tarreau - w@1wt.eu
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, version 2.1
 * exclusively.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef _COMMON_HASH_H_
#define _COMMON_HASH_H_

#include <inttypes.h>

unsigned int hash_djb2(const void *input, int len);
unsigned int hash_wt6(const void *input, int len);
unsigned int hash_sdbm(const void *input, int len);
unsigned int hash_crc32(const void *input, int len);
uint32_t hash_crc32c(const void *input, int len);

#endif /* _COMMON_HASH_H_ */
